[Pcre-svn] [457] code/trunk/src/pcre2_match.c: Tidy comment

Inizio della pagina
Delete this message
Autore: Subversion repository
Data:  
To: pcre-svn
Oggetto: [Pcre-svn] [457] code/trunk/src/pcre2_match.c: Tidy comment
Revision: 457
          http://www.exim.org/viewvc/pcre2?view=rev&revision=457
Author:   ph10
Date:     2015-12-03 17:08:23 +0000 (Thu, 03 Dec 2015)
Log Message:
-----------
Tidy comment


Modified Paths:
--------------
    code/trunk/src/pcre2_match.c


Modified: code/trunk/src/pcre2_match.c
===================================================================
--- code/trunk/src/pcre2_match.c    2015-12-03 16:58:31 UTC (rev 456)
+++ code/trunk/src/pcre2_match.c    2015-12-03 17:08:23 UTC (rev 457)
@@ -2408,8 +2408,9 @@
     ecode++;
     break;


-    /* Match a single byte, even in UTF-8 mode. This opcode really does match
-    any byte, even newline, independent of the setting of PCRE2_DOTALL. */
+    /* Match a single code unit, even in UTF-8 mode. This opcode really does
+    match any code unit, even newline. (It really should be called ANYCODEUNIT, 
+    of course - the byte name is from pre-16 bit days.) */


     case OP_ANYBYTE:
     if (eptr >= mb->end_subject)   /* DO NOT merge the eptr++ here; it must */